<?php
namespace App\Http\Controllers\V2;
use App\Http\Controllers\BaseController;
use App\Repositories\BannerRepository;
use App\Transformers\BannerTransformer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use League\Fractal\Pagination\IlluminatePaginatorAdapter;
use League\Fractal\Resource\Collection;
use League\Fractal\Manager;
/**
 * Created by PhpStorm.
 * User: durong
 * Date: 2019/6/10
 * Time: 下午18:51
 */

class BannerController extends BaseController
{
    public function __construct(BannerRepository $bannerRepository)
    {
        $this->bannerRepository = $bannerRepository;
    }

    //banner列表
    public function lists(Request $request)
    {
        $banner = $this->bannerRepository->index($request->all());

        $fractal = new Manager();
        $resource = new Collection($banner, new BannerTransformer());
        $resource->setPaginator(new IlluminatePaginatorAdapter($banner));
        $data = $fractal->createData($resource)->toArray();
        $data['extra'] = [
            'filters' => [
                'id',
                'name',
                'is_open'
            ],
            'columns' => [
                'id',
                'tpl_id',
                'rule',
                'area_type',
                'name',
                'link_content_id',
                'image',
                'type',
                'use_background',
                'status',
                'is_open',
                'updated_at',
            ]
        ];
        return $data;

    }

    //新增banner
    public function bannerSet(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'use_background' => ['required',Rule::in(0,1)],
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }

        return  $this->bannerRepository->bannerSets($request->all());

    }

    //修改banner
    public function edit(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|exists:config_banner',
        ]);

        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->bannerRepository->edit($request->all());
    }

    //删除banner
    public function bannerDelete(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|exists:config_banner'
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return $this->bannerRepository->bannerDelete($request->only('id'));

    }

    //修改banner状态
    public function editStatus(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|exists:config_banner',
            'is_open' => ['required', Rule::in(0,1)],
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }

        return  $this->bannerRepository->editStatus($request->all());
    }


}